summaryrefslogtreecommitdiffstats
path: root/certmanager/lib/backends/qgpgme/qgpgmejob.h
diff options
context:
space:
mode:
Diffstat (limited to 'certmanager/lib/backends/qgpgme/qgpgmejob.h')
-rw-r--r--certmanager/lib/backends/qgpgme/qgpgmejob.h34
1 files changed, 17 insertions, 17 deletions
diff --git a/certmanager/lib/backends/qgpgme/qgpgmejob.h b/certmanager/lib/backends/qgpgme/qgpgmejob.h
index 4a03d7d9..4f393cfb 100644
--- a/certmanager/lib/backends/qgpgme/qgpgmejob.h
+++ b/certmanager/lib/backends/qgpgme/qgpgmejob.h
@@ -20,18 +20,18 @@
In addition, as a special exception, the copyright holders give
permission to link the code of this program with any edition of
- the Qt library by Trolltech AS, Norway (or with modified versions
- of Qt that use the same license as Qt), and distribute linked
+ the TQt library by Trolltech AS, Norway (or with modified versions
+ of TQt that use the same license as TQt), and distribute linked
combinations including the two. You must obey the GNU General
Public License in all respects for all of the code used other than
- Qt. If you modify this file, you may extend this exception to
+ TQt. If you modify this file, you may extend this exception to
your version of the file, but you are not obligated to do so. If
you do not wish to do so, delete this exception statement from
your version.
*/
-#ifndef __KLEO_QGPGMEJOB_H__
-#define __KLEO_QGPGMEJOB_H__
+#ifndef __KLEO_TQGPGMEJOB_H__
+#define __KLEO_TQGPGMEJOB_H__
#include <gpgmepp/interfaces/progressprovider.h>
#include <gpgmepp/interfaces/passphraseprovider.h>
@@ -54,7 +54,7 @@ namespace Kleo {
}
namespace QGpgME {
- class QByteArrayDataProvider;
+ class TQByteArrayDataProvider;
}
class TQString;
@@ -63,14 +63,14 @@ class TQStringList;
namespace Kleo {
/** This is a hackish helper class to avoid code duplication in this
- backend's Kleo::Job subclasses. It tqcontains several workarounds
+ backend's Kleo::Job subclasses. It contains several workarounds
for tqmoc/signal/slot shortcomings, most of which the author of
- this thinks are Qt bugs (lazy implementations), first and
+ this thinks are TQt bugs (lazy implementations), first and
foremost the inability of tqmoc to handle inheritance from
- multiple QObject-derived subclasses.
+ multiple TQObject-derived subclasses.
To use it, inherit from the Job-subclass, then from this class,
- add QGPGME_JOB to just after Q OBJECT and implement
+ add TQGPGME_JOB to just after Q OBJECT and implement
doOperationDoneEvent() by emitting your variant of the result()
signal there. Pass "this" as the first argument this QGpgMEJOb's
ctor. The rest is dealt with automatically.
@@ -98,9 +98,9 @@ namespace Kleo {
void setChunkSize( unsigned int size );
/*! @return current chunksize */
unsigned int chunkSize() const { return mChunkSize; }
/*! Creates an empty GpgME::Data/QGpgME::QByteArrayDataProvider pair */
void createOutData();
/*! Creates a GpgME::Data/QGpgME::QByteArrayDataProvider pair,
filled with the contents of \a in */
void createInData( const TQByteArray & in );
/*! Sets the list of signing keys */
@@ -135,12 +135,12 @@ namespace Kleo {
Kleo::Job * mThis;
GpgME::Context * mCtx;
GpgME::Data * mInData;
- QGpgME::QByteArrayDataProvider * mInDataDataProvider;
+ QGpgME::TQByteArrayDataProvider * mInDataDataProvider;
GpgME::Data * mOutData;
- QGpgME::QByteArrayDataProvider * mOutDataDataProvider;
+ QGpgME::TQByteArrayDataProvider * mOutDataDataProvider;
private:
const char* * mPatterns;
- // holds the entry - if any - in mPattern that was tqreplaced with
+ // holds the entry - if any - in mPattern that was replaced with
// NULL to create a temporary end-of-array marker for gpgme:
const char * mReplacedPattern;
unsigned int mNumPatterns;
@@ -156,6 +156,6 @@ namespace Kleo {
#define make_progress_emitter private: void doEmitProgressSignal( const TQString & what, int cur, int tot ) { emit progress( what, cur, tot ); }
#define make_done_emitter private: void doEmitDoneSignal() { emit done(); }
#define make_auditLogAsHtml private: TQString auditLogAsHtml() const { return QGpgMEJob::auditLogAsHtml(); } GpgME::Error auditLogError() const { return QGpgMEJob::auditLogError(); }
-#define QGPGME_JOB make_slot_cancel make_progress_emitter make_done_emitter make_auditLogAsHtml
+#define TQGPGME_JOB make_slot_cancel make_progress_emitter make_done_emitter make_auditLogAsHtml
-#endif // __KLEO_QGPGMEJOB_H__
+#endif // __KLEO_TQGPGMEJOB_H__
@@ -98,9 +98,9 @@ namespace Kleo {
/*! @return current chunksize */
unsigned int chunkSize() const { return mChunkSize; }
- /*! Creates an empty GpgME::Data/QGpgME::QByteArrayDataProvider pair */
+ /*! Creates an empty GpgME::Data/QGpgME::TQByteArrayDataProvider pair */
void createOutData();
@@ -98,9 +98,9 @@ namespace Kleo {
void createOutData();
- /*! Creates a GpgME::Data/QGpgME::QByteArrayDataProvider pair,
+ /*! Creates a GpgME::Data/QGpgME::TQByteArrayDataProvider pair,
filled with the contents of \a in */
void createInData( const TQByteArray & in );